@@ -4,7 +4,6 @@ import yaml
 def load(args, data):
     """
     Load an answers file
-    Of note, answers could actually be stuff in the questions file
     """
     file = args.get("input_file")
     if not file:
@@ -13,5 +12,10 @@ def load(args, data):
     with open(file, encoding="UTF-8") as fd:
         answers = yaml.safe_load(fd)
 
-    data["answers"] = answers.get("answers")
+    # Copy answers without emptying out values that could have been present
+    # in questions file.
+    if "answers" not in data:
+        data["answers"] = {}
+    for k, v in answers.get("answers").items():
+        data["answers"][k] = v
     return data
