@@ -6,6 +6,7 @@ Source: https://github.com/cookiecutter/cookiecutter
 import sys
 
 from jinja2 import Environment, StrictUndefined
+from jinja2.nativetypes import NativeEnvironment
 
 
 class ExtensionLoaderMixin:
@@ -24,13 +25,17 @@ class ExtensionLoaderMixin:
             "scaffold.extensions.SlugifyExtension",
             "jinja2_time.TimeExtension",
         ]
+
         extensions += context or []
 
         # Add template path to sys.path for loading
         if path is not None:
             sys.path.append(path)
 
-        super().__init__(extensions=extensions, **kwargs)
+        try:
+            super().__init__(extensions=extensions, **kwargs)
+        except ModuleNotFoundError as err:
+            sys.exit(f'error: failed to load extensions from "{path}" directory: {err}')
 
 
 class StrictEnvironment(ExtensionLoaderMixin, Environment):
@@ -49,3 +54,21 @@ class StrictEnvironment(ExtensionLoaderMixin, Environment):
         """
         super().__init__(**kwargs)
         self.undefined = StrictUndefined
+
+
+class StrictNativeEnvironment(ExtensionLoaderMixin, NativeEnvironment):
+    """
+    Create strict Jinja2 environment.
+
+    Jinja2 environment will raise error on undefined variable in template-
+    rendering context.
+    """
+
+    def __init__(self, *_args, **kwargs):
+        """
+        Set the standard Cookiecutter StrictEnvironment.
+
+        Also loading extensions defined in mk-scaffold 'extensions' key.
+        """
+        super().__init__(**kwargs)
+        self.undefined = StrictUndefined
